#ifndef VKAR_PHASE_FRAMESET_H
#define VKAR_PHASE_FRAMESET_H

#include <vector>
#include "Frame.h"
#include "Point.h"

/** A rectangular pixelized array with double values in windowed regions.
* The class contains rectangular non-overlapping subregions on a
* commensurate common pixel basis. Values in the interstitial regions between
* these windows are not stored. The main functionality is an efficient
* storage scheme for a big rectangular region (super-array) with internal
* stripe and sub-block geometry.
* @author R. J. Mathar
* @since 2010-10-31
*/
class FrameSet {
public:
	/** The subwindows.
	*/
	std::vector<Frame> wd ;

	/* Partial sum of the areas, starting with areas[0]=0.
	* Contains one more element than wd[].
	*/
	std::vector<int> areas ;



	FrameSet() ;
	FrameSet(const Frame & windo) ;

	FrameSet & operator+= (const Frame & windo) ;

	FrameSet & operator+= (const FrameSet & windo) ;

	void boundbox(int bb[4]) const;

	int area() const ;

	void nonoverl() ;

	int covers(int x, int y) const ;

	void loc(int idx, int widx[3]) const ;

protected:

private:

	int covers(std::vector<int> &xedgvec, std::vector<int> & yedgvec, int xidx, int yidx) const ;
} ;

std::ostream & operator<<(std::ostream & os, const FrameSet & fr) ;
#endif /* VKAR_PHASE_FRAMESET_H */
