#ifndef VKAR_PHASE_PHASCR_H
#define VKAR_PHASE_PHASCR_H

#include <iostream>
#include "FrameSet.h"
#include "RecPixSupArr.h"

/** 
* @author R. J. Mathar
* @since 2010-10-31
*/
template <class TYP> class PhaScr : public RecPixSupArr<TYP> {
public:
	/** pixel scale, meters for each pixel's edge
	*/
	double pixscal ;

	/** The eigenvalue.
	* More acurately, if the Karhunen-Loeve equation is
	* \f[ \int d^2r' C_\varphi(r,r') K_j(r') = {\cal B}^2 K_j(r)\f]
	* for modes \f$K_j\f$, then the value of this variable is the square
	* root of the eigenvalue, that is, \f${\cal B}\f$.
	* One may compare results with the values of the scaled \f$\lambda^2\f$
	* shown in 
	* \latexonly
	* \cite{MatharWRCM20}
	* \endlatexonly
	* for outputs containing a single stripe by using the area, Fried
	* parameter and Kolomgorov exponent as documented in the publication.
	*/
	double eval ;

	PhaScr(const RecPixSupArr<TYP> & fr, const double pscal) ;

	void plot(std::ostream & os, const FrameSet & fs) ;
protected:

private:
} ;


#endif /* VKAR_PHASE_PHASCR_H */
