#include "RecPixArr.h"

/** Default ctor.
* This is equivalent to creating a field with no pixels.
*/
export template <class TYP> RecPixArr<TYP>::RecPixArr()
{
	nx =ny =0 ;
}

/** Ctor of a flat screen with constant value.
* @param[in] dimx The number of pixels in the x direction
* @param[in] dimy The number of pixels in the y direction
* @param[in] fvalue A constant value assigned to all pixels.
*/
export template <class TYP> RecPixArr<TYP>::RecPixArr(int dimx, int dimy, TYP fvalue) 
	: nx(dimx), ny(dimy), val(fvalue,dimx*dimy)
{
}

/** Ctor of a screen with all pixels known.
* @param[in] dimx The number of pixels in the x direction
* @param[in] dimy The number of pixels in the y direction
* @param[in] fvalue The vector of pixel values in standard row[0], row[1],..order
*/
export template <class TYP> RecPixArr<TYP>::RecPixArr(int dimx, int dimy, std::valarray<TYP> & fvalue) 
	: nx(dimx), ny(dimy), val(fvalue)
{
}

/** Set all pixels.
* @param[in] fval The values that replace the current frame.
*/
export template <class TYP> template <class TYPV> void RecPixArr<TYP>::set(const TYPV *fval)
{
	/* Copy fval[0..nx*ny-1] to val[]
	*/
	for(int i=0 ; i < nx*ny ; i++)
		val[i] = fval[i] ;
}



/** Read the value of a pixel.
* @param x The 0-based index in the x direction
* @param y The 0-based index in the y direction
* @return The current value at the specified address.
* Request to read a pixel outside the region defined by the array return zero.
*/
export template <class TYP> TYP RecPixArr<TYP>::at(int x, int y) const
{
	/* The linearized index into the flattened array of the values
	* according to the local storage scheme.
	*/
	const int linidx = x + nx*y ;
	if ( linidx >=0 && linidx < val.size() )
		return val[linidx] ;
	else
		return 0. ;
}




/** The integer area in units of pixels squared.
*/
template <class TYP> int RecPixArr<TYP>::area() const
{
	return nx*ny ;
}

/** Shrink to a zero-size (no-pixel) array.
*/
template <class TYP> void RecPixArr<TYP>::clear()
{
	nx = ny = 0 ;
	val.resize(0,0.) ;
}

/* Explicit instantiation to prevent linker complaints with template classes
*/
template class RecPixArr<double> ;
template class RecPixArr<float> ;
template class RecPixArr<int> ;
template class RecPixArr<short> ;
template class RecPixArr<long> ;
template void RecPixArr<double>::set(const double *fval) ;
template void RecPixArr<float>::set(const double *fval) ;
